setup.py — setupjavax documentation

# setup.py

The setupjavax provides the extensions for the standard setup.py of the setuptools / distutils.

## SYNOPSIS

    setup.py [OPTIONS] [COMMANDS]

## OPTIONS

See:

- setup.py: [setuptools] and [setuppy]

- extensions by setupjavax: [Global-OPTIONS]

## COMMANDS

See:

- setup.py: [setuptools] and [setuppy]

- extensions by setupjavax: [COMMANDS-with-context-OPTIONS]

## DESCRIPTION

The call interface ‘setuptools’ with extension by ‘setupjavax’.

## SEE ALSO

setup.py, setupjavax, [setuptools], [distutils]

## LICENSE

Artistic-License-2.0 + Forced-Fairplay-Constraints

## COPYRIGHT

Copyright (C)2019 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez